diff --git a/app/controllers/projects_controller.rb b/app/controllers/projects_controller.rb
index c93c97a..06db7db 100644
--- a/app/controllers/projects_controller.rb
+++ b/app/controllers/projects_controller.rb
@@ -128,7 +128,7 @@ class ProjectsController < ApplicationController
   # Show @project
   def show
     @users_by_role = @project.users_by_role
-    @subprojects = @project.children.visible.all
+    @subprojects = @project.all_visible_children
     @news = @project.news.find(:all, :limit => 5, :include => [ :author, :project ], :order => "#{News.table_name}.created_on DESC")
     @trackers = @project.rolled_up_trackers
 
diff --git a/app/models/project.rb b/app/models/project.rb
index c030930..fc4ec4d 100644
--- a/app/models/project.rb
+++ b/app/models/project.rb
@@ -562,6 +562,16 @@ class Project < ActiveRecord::Base
     project_hierarchy = parents | descendants # Set union
   end
 
+  # Returns an ordered list containing all descendant projects that are
+  # visible to the current user
+  def all_visible_children(user = nil)
+    user ||= User.current
+    Project.find(:all,    
+      :conditions => ["#{Project.visible_by(user)} AND (#{Project.table_name}.lft > ?) AND (#{Project.table_name}.rgt < ?)", lft, rgt],
+      :order => "lft"
+    )
+  end
+
   # Returns an auto-generated project identifier based on the last identifier used
   def self.next_identifier
     p = Project.find(:first, :order => 'created_on DESC')
diff --git a/app/views/projects/show.rhtml b/app/views/projects/show.rhtml
index b7036a5..f3c6e11 100644
--- a/app/views/projects/show.rhtml
+++ b/app/views/projects/show.rhtml
@@ -12,16 +12,16 @@
 	</div>
 	<ul>
 	<% unless @project.homepage.blank? %><li><%=l(:field_homepage)%>: <%= auto_link(h(@project.homepage)) %></li><% end %>
-  <% if @subprojects.any? %>
- 	<li><%=l(:label_subproject_plural)%>:
-	    <%= @subprojects.collect{|p| link_to(h(p), :action => 'show', :id => p)}.join(", ") %></li>
-  <% end %>
 	<% @project.visible_custom_field_values.each do |custom_value| %>
 	<% if !custom_value.value.blank? %>
 	   <li><%= h(custom_value.custom_field.name) %>: <%=h show_value(custom_value) %></li>
 	<% end %>
 	<% end %>
 	</ul>
+  <% if @subprojects.any? %>
+	<h3><%=l(:label_subproject_plural)%>:</h3>
+	<%= render_project_hierarchy(@subprojects) %>
+  <% end %>
 
   <% if User.current.allowed_to?(:view_issues, @project) %>
   <div class="issues box">
